@@ -135,6 +135,9 @@ private slots:
     //! Invoked when the Call initiators list changes
     void onCallInitiatorsChange(bool bSave = true);
 
+    //! Invoked when the timer based cleanup of logs array is invoked
+    void onCleanupLogsArray();
+
 private:
     void initLogging ();
 
@@ -227,6 +230,14 @@ private:
     //! Map between the voice mail link and its temp file name
     QMap<QString,QString> mapVmail;
 
+    QMutex          logMutex;
+    //! This holds a circular buffer of log messages that will be shown by QML
+    QStringList     arrLogMsgs;
+    //! Logs display timer
+    QTimer          logsTimer;
+    //! kick timer
+    bool            bKickLocksTimer;
+
 #if MOSQUITTO_CAPABLE
     //! This holds the thread that communicates with the mosquitto server.
     MqClientThread  mqThread;
